@@ -29,6 +29,8 @@
 #include <gdk/gdkkeysyms.h>
 #include <gconf/gconf-client.h>
 
+#include <string.h>
+
 enum {
     CMD_MOUNT_OR_PLAY,
     CMD_UNMOUNT,
@@ -48,7 +50,9 @@ static void     drive_button_reset_popup  (DriveButton    *self);
 static void     drive_button_ensure_popup (DriveButton    *self);
 
 static void     drive_button_destroy      (GtkObject      *object);
+#if 0
 static void     drive_button_unrealize    (GtkWidget      *widget);
+#endif /* 0 */
 static gboolean drive_button_button_press (GtkWidget      *widget,
 					   GdkEventButton *event);
 static gboolean drive_button_key_press    (GtkWidget      *widget,
@@ -143,6 +147,7 @@ drive_button_destroy (GtkObject *object)
 	(* GTK_OBJECT_CLASS (drive_button_parent_class)->destroy) (object);
 }
 
+#if 0
 static void
 drive_button_unrealize (GtkWidget *widget)
 {
@@ -153,6 +158,7 @@ drive_button_unrealize (GtkWidget *widget)
     if (GTK_WIDGET_CLASS (drive_button_parent_class)->unrealize)
 	(* GTK_WIDGET_CLASS (drive_button_parent_class)->unrealize) (widget);
 }
+#endif /* 0 */
 
 /* the following function is adapted from gtkmenuitem.c */
 static void
@@ -422,11 +428,13 @@ drive_button_reset_popup (DriveButton *self)
     self->popup_menu = NULL;
 }
 
+#if 0
 static void
 popup_menu_detach (GtkWidget *attach_widget, GtkMenu *menu)
 {
     DRIVE_BUTTON (attach_widget)->popup_menu = NULL;
 }
+#endif /* 0 */
 
 static char *
 escape_underscores (const char *str)
@@ -586,6 +594,7 @@ mount_result (gboolean succeeded,
 
 /* copied from gnome-volume-manager/src/manager.c maybe there is a better way than
  * duplicating this code? */
+
 /*
  * gvm_run_command - run the given command, replacing %d with the device node
  * and %m with the given path
@@ -627,13 +636,73 @@ gvm_run_command (const char *device, const char *command, const char *path)
 
 	g_spawn_async (g_get_home_dir (), argv, NULL, 0, NULL, NULL,
 		       NULL, &error);
-	if (error)
-		warn ("failed to exec %s: %s\n", exec->str, error->message);
+	if (error) {
+		g_warning ("failed to exec %s: %s\n", exec->str, error->message);
+		g_error_free (error);
+	}
 
 	g_string_free (exec, TRUE);
 	g_free (new_command);
 }
 
+/*
+ * gvm_check_dvd_only - is this a Video DVD?
+ *
+ * Returns TRUE if this was a Video DVD and FALSE otherwise.
+ * (the original in gvm was also running the autoplay action,
+ * I removed that code, so I renamed from gvm_check_dvd to
+ * gvm_check_dvd_only)
+ */
+static gboolean
+gvm_check_dvd_only (const char *udi, const char *device, const char *mount_point)
+{
+	char *path;
+	gboolean retval;
+	
+	path = g_build_path (G_DIR_SEPARATOR_S, mount_point, "video_ts", NULL);
+	retval = g_file_test (path, G_FILE_TEST_IS_DIR);
+	g_free (path);
+	
+	/* try the other name, if needed */
+	if (retval == FALSE) {
+		path = g_build_path (G_DIR_SEPARATOR_S, mount_point,
+				     "VIDEO_TS", NULL);
+		retval = g_file_test (path, G_FILE_TEST_IS_DIR);
+		g_free (path);
+	}
+	
+	return retval;
+}
+/* END copied from gnome-volume-manager/src/manager.c */
+
+static gboolean
+check_dvd_video (GnomeVFSVolume *volume)
+{
+	char *device_path = gnome_vfs_volume_get_device_path (volume);
+	char *uri = gnome_vfs_volume_get_activation_uri (volume);
+	char *mount_path = gnome_vfs_get_local_path_from_uri (uri);
+	char *udi = gnome_vfs_volume_get_hal_udi (volume);
+
+	gboolean result = gvm_check_dvd_only (udi, device_path, mount_path);
+
+	g_free (device_path);
+	g_free (udi);
+	g_free (uri);
+	g_free (mount_path);
+
+	return result;
+}
+
+static gboolean
+check_audio_cd (DriveButton *self, GnomeVFSVolume *volume)
+{
+	char *activation_uri = gnome_vfs_volume_get_activation_uri (volume);
+	// we have an audioCD if the activation URI starts by 'cdda://'
+	gboolean result = (strncmp ("cdda://", activation_uri, 7) == 0);
+	g_free (activation_uri);
+	return result;
+}
+
 static void
 run_command (DriveButton *self, const char *command)
 {
@@ -729,6 +798,9 @@ drive_button_ensure_popup (DriveButton *self)
     if (self->popup_menu) return;
 
     if (self->drive) {
+	GnomeVFSVolume *volume = NULL;
+	GList *volumes;
+
 	if (!gnome_vfs_drive_is_connected (self->drive)) return;
 
 	device_type = gnome_vfs_drive_get_device_type (self->drive);
@@ -746,6 +818,34 @@ drive_button_ensure_popup (DriveButton *self)
 	} else {
 	    action = CMD_MOUNT_OR_PLAY;
 	}
+    
+	volumes = gnome_vfs_drive_get_mounted_volumes (self->drive);
+	if (volumes != NULL)
+	{
+		volume = GNOME_VFS_VOLUME (volumes->data);
+		device_type = gnome_vfs_volume_get_device_type (volume);
+	}
+
+	/*
+	 * For some reason, on my computer, I get GNOME_VFS_DEVICE_TYPE_CDROM
+	 * also for DVDs and Audio CDs, while for DVD the icon is correctly the
+	 * one for DVDs and for Audio CDs the description correctly that of an
+	 * audio CD? So i have this hack.
+	 */
+	if (volume)
+	{
+		if (check_dvd_video (volume))
+		{
+			device_type = GNOME_VFS_DEVICE_TYPE_VIDEO_DVD;
+		}
+		if (check_audio_cd (self, volume))
+		{
+			device_type = GNOME_VFS_DEVICE_TYPE_AUDIO_CD;
+		}
+	}
+
+	g_list_foreach (volumes, (GFunc)gnome_vfs_volume_unref, NULL);
+	g_list_free (volumes);
     } else {
 	if (!gnome_vfs_volume_is_mounted (self->volume)) return;
 
@@ -762,38 +862,6 @@ drive_button_ensure_popup (DriveButton *self)
 	}
     }
 
-	GList *volumes;
-	GnomeVFSVolume *volume = NULL;
-	GnomeVFSDeviceType volume_type = device_type;
-
-	volumes = gnome_vfs_drive_get_mounted_volumes (self->drive);
-	if (volumes != NULL)
-	{
-		volume = GNOME_VFS_VOLUME (volumes->data);
-		volume_type = gnome_vfs_volume_get_device_type (volume);
-	}
-
-	/*
-	 * For some reason, on my computer, I get GNOME_VFS_DEVICE_TYPE_CDROM
-	 * also for DVDs and Audio CDs, while for DVD the icon is correctly the
-	 * one for DVDs and for Audio CDs the description correctly that of an
-	 * audio CD? So i have this hack.
-	 */
-	if (volume)
-	{
-		if (strcmp (gnome_vfs_volume_get_icon (volume), "gnome-dev-dvd") == 0)
-		{
-			volume_type = GNOME_VFS_DEVICE_TYPE_VIDEO_DVD;
-		}
-		if (strcmp (gnome_vfs_volume_get_display_name (volume), "Audio Disc") == 0)
-		{
-			volume_type = GNOME_VFS_DEVICE_TYPE_AUDIO_CD;
-		}
-	}
-
-	g_list_foreach (volumes, (GFunc)gnome_vfs_volume_unref, NULL);
-	g_list_free (volumes);
-
     self->popup_menu = gtk_menu_new ();
 
     /* make sure the display name doesn't look like a mnemonic */
@@ -804,16 +872,16 @@ drive_button_ensure_popup (DriveButton *self)
 	GCallback callback = G_CALLBACK (open_drive);
 	const char *action_icon = GTK_STOCK_OPEN;
 
-	switch (volume_type) {
+	switch (device_type) {
 	case GNOME_VFS_DEVICE_TYPE_VIDEO_DVD:
 		label = g_strdup (_("_Play DVD"));
 		callback = G_CALLBACK (play_dvd);
-		action_icon = GTK_STOCK_CDROM;
+		action_icon = GTK_STOCK_MEDIA_PLAY;
 		break;
 	case GNOME_VFS_DEVICE_TYPE_AUDIO_CD:
 		label = g_strdup (_("_Play CD"));
 		callback = G_CALLBACK (play_cda);
-		action_icon = GTK_STOCK_CDROM;
+		action_icon = GTK_STOCK_MEDIA_PLAY;
 		break;
 	default:
 		label = g_strdup_printf (_("_Open %s"), display_name);
