@@ -27,6 +27,7 @@
 
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtkimage.h>
+#include <gtk/gtktooltips.h>
 #include <gconf/gconf-client.h>
 #include <panel-applet-gconf.h>
 #include <gst/gst.h>
@@ -67,9 +68,9 @@ typedef struct _GnomeVolumeApplet {
 
   /* element */
   GstMixer *mixer;
-  GstMixerTrack *track;
   gboolean lock;
   gint state;
+  GList *tracks;
 
   /* timeout ID, used to decouple on disposal */
   guint timeout;
@@ -79,12 +80,19 @@ typedef struct _GnomeVolumeApplet {
 
   /* icon theme */
   GtkIconTheme *icon_theme;
+
+  /* use same object for setting tooltop */
+  GtkTooltips *tooltips;
+  gboolean force_next_update;
 } GnomeVolumeApplet;
 
 typedef struct _GnomeVolumeAppletClass {
   PanelAppletClass klass;
 } GnomeVolumeAppletClass;
 
+void     gnome_volume_applet_adjust_volume (GstMixer      *mixer,
+					    GstMixerTrack *track,
+					    int            volume);
 GType    gnome_volume_applet_get_type (void);
 gboolean gnome_volume_applet_setup    (GnomeVolumeApplet *applet,
 				       GList             *elements);
