@@ -18,6 +18,7 @@
  */
 
 #include <config.h>
+#include <string.h>
 #include "stickynotes_applet.h"
 #include "stickynotes_applet_callbacks.h"
 #include "stickynotes.h"
@@ -32,6 +33,7 @@ StickyNotes *stickynotes = NULL;
 /* Popup menu on the applet */
 static const BonoboUIVerb stickynotes_applet_menu_verbs[] = 
 {
+        BONOBO_UI_UNSAFE_VERB ("new_note", menu_new_note_cb),
         BONOBO_UI_UNSAFE_VERB ("destroy_all", menu_destroy_all_cb),
         BONOBO_UI_UNSAFE_VERB ("preferences", menu_preferences_cb),
         BONOBO_UI_UNSAFE_VERB ("help", menu_help_cb),
@@ -119,8 +121,6 @@ stickynotes_make_prelight_icon (GdkPixbuf *dest, GdkPixbuf *src, int shift)
 void
 stickynotes_applet_init (PanelApplet *panel_applet)
 {	
-	GnomeIconTheme *icon_theme;
-	gchar *sticky_icon;
 	GnomeClient *client;
 
 	stickynotes = g_new(StickyNotes, 1);
@@ -128,19 +128,14 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	stickynotes->notes = NULL;
 	stickynotes->applets = NULL;
 
-	icon_theme = gnome_icon_theme_new ();
-	sticky_icon = gnome_icon_theme_lookup_icon (icon_theme,
-			"stock_notes", 48, NULL, NULL);
 	/* Register size for icons */
 	gtk_icon_size_register ("stickynotes_icon_size", 8,8);
 
-	if (sticky_icon) {
-		gnome_window_icon_set_default_from_file (sticky_icon);
-		stickynotes->icon_normal = gdk_pixbuf_new_from_file (
-				sticky_icon, NULL);
-	}
-	g_free (sticky_icon);
-	g_object_unref (icon_theme);
+	gtk_window_set_default_icon_name ("stock_notes");
+
+	stickynotes->icon_normal = gtk_icon_theme_load_icon (
+			gtk_icon_theme_get_default (), "stock_notes",
+			48, 0, NULL);
 
 	stickynotes->icon_prelight = gdk_pixbuf_new (
 			gdk_pixbuf_get_colorspace (stickynotes->icon_normal),
@@ -182,6 +177,7 @@ stickynotes_applet_init (PanelApplet *panel_applet)
 	g_timeout_add (1000 * 60 * gconf_client_get_int(stickynotes->gconf,
 				GCONF_PATH "/settings/autosave_time", NULL),
 		      (GSourceFunc) applet_save_cb, NULL);
+	g_timeout_add (100, applet_check_click_on_desktop_cb, NULL);
 }
 
 /* Initialize Sticky Notes Icons */
@@ -356,7 +352,6 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 	applet->prelighted = FALSE;
 	applet->pressed = FALSE;
 
-	applet->popup_menu = NULL;
 	applet->menu_tip = NULL;
 	applet->menu_show = NULL;
 
@@ -386,7 +381,6 @@ StickyNotesApplet * stickynotes_applet_new(PanelApplet *panel_applet)
 					      NULL);
 	}
 
-	bonobo_ui_component_add_listener(panel_applet_get_popup_component(panel_applet), "show", (BonoboUIListenerFn) menu_toggle_show_cb, applet);
 	bonobo_ui_component_add_listener(panel_applet_get_popup_component(panel_applet), "lock", (BonoboUIListenerFn) menu_toggle_lock_cb, applet);
 
 	/* Connect all signals for applet management */
@@ -558,10 +552,7 @@ stickynotes_applet_update_prefs (void)
 
 void stickynotes_applet_update_menus(void)
 {
-	gboolean visible = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
-	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
-	
-	gboolean visible_writable = gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/visible", NULL);
+	gboolean locked = gconf_client_get_bool(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);	
 	gboolean locked_writable = gconf_client_key_is_writable(stickynotes->gconf, GCONF_PATH "/settings/locked", NULL);
 	
 	gboolean inconsistent = FALSE;
@@ -578,12 +569,8 @@ void stickynotes_applet_update_menus(void)
 		StickyNotesApplet *applet = g_list_nth_data(stickynotes->applets, i);
 		BonoboUIComponent *popup = panel_applet_get_popup_component(PANEL_APPLET(applet->w_applet));
 		
-		bonobo_ui_component_set_prop(popup, "/commands/show", "state", visible ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop(popup, "/commands/lock", "state", locked ? "1" : "0", NULL);
-
 		bonobo_ui_component_set_prop(popup, "/commands/lock", "inconsistent", inconsistent ? "1" : "0", NULL); /* FIXME : Doesn't work */
-
-		bonobo_ui_component_set_prop(popup, "/commands/show", "sensitive", visible_writable ? "1" : "0", NULL);
 		bonobo_ui_component_set_prop(popup, "/commands/lock", "sensitive", locked_writable ? "1" : "0", NULL);
 	}
 }
@@ -600,7 +587,7 @@ stickynotes_applet_update_tooltips (void)
 	num = g_list_length (stickynotes->notes);
 	
 	no_notes = g_strdup_printf (ngettext ("%d note", "%d notes", num), num);
-	tooltip = g_strdup_printf ("%s\n%s", _("Sticky Notes"), no_notes);
+	tooltip = g_strdup_printf ("%s\n%s", _("Show sticky notes"), no_notes);
 
 	for (l = stickynotes->applets; l; l = l->next)
 	{
@@ -619,3 +606,23 @@ stickynotes_applet_update_tooltips (void)
 	g_free (tooltip);
 	g_free (no_notes);
 }
+
+void
+stickynotes_applet_panel_icon_get_geometry (int *x, int *y, int *width, int *height)
+{
+	GtkWidget *widget;
+	GtkRequisition requisition;
+	StickyNotesApplet *applet;
+
+	applet = stickynotes->applets->data;
+
+	widget = GTK_WIDGET (applet->w_image);
+  
+	gtk_widget_size_request (widget, &requisition);
+  
+	gdk_window_get_origin (widget->window, x, y);
+  
+	*width = widget->allocation.x;
+	*height = widget->allocation.y;
+}
+
